@@ -274,6 +274,7 @@ sub source {
     return;
 }
 
+# no copyright in udebs
 sub binary {
     my ($self) = @_;
 
@@ -323,7 +324,7 @@ sub binary {
                 my $file_info = $path->file_info;
                 if ($path->is_symlink) {
                     my $normalized = $path->link_normalized;
-                    if (defined($normalized)) {
+                    if (length $normalized) {
                         $file_info = $path->file_info;
                     }
                 }
@@ -610,6 +611,10 @@ sub binary {
             if ($latest_entry->Version and $latest_entry->Version =~ /-1$/) {
                 $self->tag('new-package-should-close-itp-bug')
                   unless @{ $latest_entry->Closes };
+                $self->tag('new-package-uses-date-based-version-number',
+                    $latest_entry->Version,
+                    '(vs. 0~' . $latest_entry->Version .')')
+                  if $latest_entry->Version =~ m/^\d{8}/;
             }
             $self->tag('changelog-is-dh_make-template')
               if $changes
