@@ -63,7 +63,8 @@ my %code_priority = (
     'I' => 50,
     'P' => 60,
     'X' => 70,
-    'O' => 80,
+    'C' => 80,
+    'O' => 90,
 );
 
 my %type_priority = (
@@ -75,12 +76,26 @@ my %type_priority = (
 );
 
 sub issue_tags {
-    my ($self, $pending, $processables) = @_;
+    my ($self, $groups) = @_;
 
-    return
-      unless $pending && $processables;
+    my @processables = map { $_->get_processables } @{$groups // []};
 
-    $self->print_start_pkg($_)for @{$processables};
+    my @pending;
+    for my $processable (@processables) {
+
+        # get tags
+        my @tags = @{$processable->tags};
+
+        # associate tags with processable
+        $_->processable($processable) for @tags;
+
+        # remove circular references
+        $processable->tags([]);
+
+        push(@pending, @tags);
+    }
+
+    $self->print_start_pkg($_) for @processables;
 
     my @sorted = sort {
              defined $a->override <=> defined $b->override
@@ -89,8 +104,8 @@ sub issue_tags {
           || $type_priority{$a->processable->type}
           <=> $type_priority{$b->processable->type}
           || $a->processable->name cmp $b->processable->name
-          || $a->extra cmp $b->extra
-    } @{$pending};
+          || $a->hint cmp $b->hint
+    } @pending;
 
     $self->print_tag($_) for @sorted;
 
@@ -105,35 +120,34 @@ sub print_tag {
     my ($self, $tag) = @_;
 
     my $tag_info = $tag->info;
-    my $information = $tag->extra;
+    my $information = $tag->hint;
     my $override = $tag->override;
     my $processable = $tag->processable;
 
     my $odata = EMPTY;
     if ($override) {
         $odata = $override->{tag};
-        my $extra = $override->{extra};
-        $extra =~ s/[^[:print:]]/?/g;
-        $odata .= SPACE . $extra
-          if length $extra;
+        my $hint = $override->{hint};
+        $hint =~ s/[^[:print:]]/?/g;
+        $odata .= SPACE . $hint
+          if length $hint;
     }
 
-    $self->issuedtags->{$tag_info->tag}++;
+    $self->issuedtags->{$tag_info->name}++;
 
     $information =~ s/[^[:print:]]/?/g;
 
     my @args = (
         'tag',
         $tag_info->code,
-        $tag_info->severity,
-        $tag_info->certainty,
+        $tag_info->effective_severity,
         ($tag_info->experimental ? 'X' : EMPTY)
           . (defined $override ? 'O' : EMPTY),
         $processable->name,
         $processable->version,
         $processable->architecture,
         $processable->type,
-        $tag_info->tag,
+        $tag_info->name,
         $information,
         $odata,
     );
