@@ -25,7 +25,7 @@ use autodie;
 
 use Path::Tiny;
 
-use Lintian::File::Index;
+use Lintian::Index::Patched;
 
 use Moo::Role;
 use namespace::clean;
@@ -57,23 +57,7 @@ has patched => (
     is => 'rw',
     lazy => 1,
     default => sub {
-        my ($self) = @_;
-
-        my $patched = Lintian::File::Index->new;
-
-        # source packages can be unpacked anywhere; no anchored roots
-        my $basedir = path($self->groupdir)->child('unpacked')->stringify;
-        $patched->basedir($basedir);
-
-        $patched->fileinfo_sub(
-            sub {
-                return $self->file_info(@_);
-            });
-
-        my $dbpath = path($self->groupdir)->child('index.db')->stringify;
-        $patched->load($dbpath);
-
-        return $patched;
+        return Lintian::Index::Patched->new;
     });
 
 =item index (FILE)
@@ -130,11 +114,6 @@ L</unpacked ([FILE])> or L</index (FILE)> as is.
 
 The array will not contain the entry for the "root" of the package.
 
-NB: For source packages, please see the
-L<"index"-caveat|Lintian::Collect::Source/index (FILE)>.
-
-Needs-Info requirements for using I<sorted_index>: L<Same as index|/index (FILE)>
-
 =cut
 
 sub sorted_index {
@@ -151,11 +130,6 @@ L<entry|Lintian::File::Path> denoting the resolved path.
 The resolution is done using
 L<resolve_path|Lintian::File::Path/resolve_path([PATH])>.
 
-NB: For source packages, please see the
-L<"index"-caveat|Lintian::Collect::Source/index (FILE)>.
-
-Needs-Info requirements for using I<index_resolved_path>: L<Same as index|/index (FILE)>
-
 =cut
 
 sub index_resolved_path {
@@ -169,12 +143,11 @@ sub index_resolved_path {
 =head1 AUTHOR
 
 Originally written by Felix Lechner <felix.lechner@lease-up.com> for
-Lintian. Large portions were copied from Collect::Binary.
+Lintian.
 
 =head1 SEE ALSO
 
-lintian(1), L<Lintian::Collect>, L<Lintian::Collect::Binary>,
-L<Lintian::Collect::Source>
+lintian(1)
 
 =cut
 
